@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package SMS::Send::Nexmo;
 
-our $VERSION = '0.22';
+our $VERSION = '0.23';
 # ABSTRACT: SMS::Send backend for the Nexmo.com SMS service.
 
 use SMS::Send::Driver;
@@ -15,7 +15,6 @@ our @EXPORT = qw();
 
 our $URL = 'https://rest.nexmo.com/sms/json';
 
-
 sub new {
   my $pkg = shift;
   my %p = @_;
@@ -45,9 +44,9 @@ sub send_sms {
       from => $self->{_from},
       to   => $p{to},
       );
-  
+
   my $response = $sms->send;
-  
+
   unless ($response->is_success) {
     warn "Failure: " . $sms->errstr . "\n" if ($self->{_verbose});
     return 0;
@@ -55,23 +54,21 @@ sub send_sms {
   return 1;
 }
 
-1;
-
-
-
 1;
 
 __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
 SMS::Send::Nexmo - SMS::Send backend for the Nexmo.com SMS service.
 
 =head1 VERSION
 
-version 0.22
+version 0.23
 
 =head1 SYNOPSIS
 
@@ -101,7 +98,7 @@ functions than just sending messages; please use L<Nexmo::SMS> directly.
 
 =head1 AUTHOR
 
-Michiel Beijen <michiel.beijen@gmail.com>
+Michiel Beijen <michielb@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
